==> fltk-docs-1.3.3-5-aarch64.pkg.tar.xz: usr/share/doc/fltk/classFl__RGB__Image.js <==
var classFl__RGB__Image =
[
    [ "Fl_RGB_Image", "classFl__RGB__Image.html#a83abf3e002d2b7db9a8b4dd9caf21df5", null ],
    [ "Fl_RGB_Image", "classFl__RGB__Image.html#a90cf475d42e9f9220805389659e9d729", null ],
    [ "~Fl_RGB_Image", "classFl__RGB__Image.html#adb61a692286a411bbd7742ca42792949", null ],
    [ "color_average", "classFl__RGB__Image.html#a38470ac9fec061ae82fc1b68382f5b83", null ],
    [ "copy", "classFl__RGB__Image.html#aeb25a6d3697569ec776805b002a51ac2", null ],
    [ "copy", "classFl__RGB__Image.html#a125b8ac01c0f87e296ffcd21b5ce16a7", null ],
    [ "desaturate", "classFl__RGB__Image.html#a0bffa2d2b3f0db0c22cddd191949e1fe", null ],
    [ "draw", "classFl__RGB__Image.html#aa28d6e365c896d117880f5518e7040f1", null ],
    [ "draw", "classFl__RGB__Image.html#afdaf0526d2d09c3843822accb571b09f", null ],
    [ "label", "classFl__RGB__Image.html#ab58a7db5927c3f6b29633af1359f8e8e", null ],
    [ "label", "classFl__RGB__Image.html#a41c96d356632258d97c65ee9d342208e", null ],
    [ "uncache", "classFl__RGB__Image.html#aa3a8553338909f95bf98959a14374793", null ],
    [ "Fl_GDI_Graphics_Driver", "classFl__RGB__Image.html#afdd004b46bf519fc92d7de53fa9e8f33", null ],
    [ "Fl_Quartz_Graphics_Driver", "classFl__RGB__Image.html#a17e52a458f8b74600a08e84e14dd7788", null ],
    [ "Fl_Xlib_Graphics_Driver", "classFl__RGB__Image.html#a0dc2ea59692c09f5b9d1f13cc66ad01d", null ],
    [ "alloc_array", "classFl__RGB__Image.html#ab30c313c5eeb1b4f4f729b822a482860", null ],
    [ "array", "classFl__RGB__Image.html#a1a47fb9450614a398a9aa9db7289876d", null ]
];

==> fltk-docs-1.3.4-1-aarch64.pkg.tar.xz: usr/share/doc/fltk/classFl__RGB__Image.js <==
var classFl__RGB__Image =
[
    [ "Fl_RGB_Image", "classFl__RGB__Image.html#a83abf3e002d2b7db9a8b4dd9caf21df5", null ],
    [ "Fl_RGB_Image", "classFl__RGB__Image.html#a90cf475d42e9f9220805389659e9d729", null ],
    [ "~Fl_RGB_Image", "classFl__RGB__Image.html#adb61a692286a411bbd7742ca42792949", null ],
    [ "color_average", "classFl__RGB__Image.html#a38470ac9fec061ae82fc1b68382f5b83", null ],
    [ "copy", "classFl__RGB__Image.html#aeb25a6d3697569ec776805b002a51ac2", null ],
    [ "copy", "classFl__RGB__Image.html#a125b8ac01c0f87e296ffcd21b5ce16a7", null ],
    [ "desaturate", "classFl__RGB__Image.html#a0bffa2d2b3f0db0c22cddd191949e1fe", null ],
    [ "draw", "classFl__RGB__Image.html#aa28d6e365c896d117880f5518e7040f1", null ],
    [ "draw", "classFl__RGB__Image.html#afdaf0526d2d09c3843822accb571b09f", null ],
    [ "label", "classFl__RGB__Image.html#ab58a7db5927c3f6b29633af1359f8e8e", null ],
    [ "label", "classFl__RGB__Image.html#a41c96d356632258d97c65ee9d342208e", null ],
    [ "uncache", "classFl__RGB__Image.html#aa3a8553338909f95bf98959a14374793", null ],
    [ "Fl_GDI_Graphics_Driver", "classFl__RGB__Image.html#afdd004b46bf519fc92d7de53fa9e8f33", null ],
    [ "Fl_GDI_Printer_Graphics_Driver", "classFl__RGB__Image.html#a0c87ae869fae93aeba9ddf11e9a1100c", null ],
    [ "Fl_Quartz_Graphics_Driver", "classFl__RGB__Image.html#a17e52a458f8b74600a08e84e14dd7788", null ],
    [ "Fl_Xlib_Graphics_Driver", "classFl__RGB__Image.html#a0dc2ea59692c09f5b9d1f13cc66ad01d", null ],
    [ "alloc_array", "classFl__RGB__Image.html#ab30c313c5eeb1b4f4f729b822a482860", null ],
    [ "array", "classFl__RGB__Image.html#a1a47fb9450614a398a9aa9db7289876d", null ]
];
